pub struct PgpKeyPair { /* private fields */ }Implementations
Sourceimpl PgpKeyPair
impl PgpKeyPair
Sourcepub fn label(&self) -> &str
pub fn label(&self) -> &str
Returns the label used to create this keypair.
Examples
let fx = Factory::random();
let kp = fx.pgp("my-svc", PgpSpec::ed25519());
assert_eq!(kp.label(), "my-svc");Sourcepub fn fingerprint(&self) -> &str
pub fn fingerprint(&self) -> &str
Returns the OpenPGP key fingerprint.
Sourcepub fn private_key_binary(&self) -> &[u8] ⓘ
pub fn private_key_binary(&self) -> &[u8] ⓘ
Binary transferable secret key bytes.
Sourcepub fn private_key_armored(&self) -> &str
pub fn private_key_armored(&self) -> &str
Armored transferable secret key.
Sourcepub fn public_key_binary(&self) -> &[u8] ⓘ
pub fn public_key_binary(&self) -> &[u8] ⓘ
Binary transferable public key bytes.
Sourcepub fn public_key_armored(&self) -> &str
pub fn public_key_armored(&self) -> &str
Armored transferable public key.
Sourcepub fn write_private_key_armored(&self) -> Result<TempArtifact, Error>
pub fn write_private_key_armored(&self) -> Result<TempArtifact, Error>
Write the armored private key to a tempfile.
Sourcepub fn write_public_key_armored(&self) -> Result<TempArtifact, Error>
pub fn write_public_key_armored(&self) -> Result<TempArtifact, Error>
Write the armored public key to a tempfile.
Sourcepub fn private_key_armored_corrupt(&self, how: CorruptPem) -> String
pub fn private_key_armored_corrupt(&self, how: CorruptPem) -> String
Produce a corrupted armored private key variant.
Sourcepub fn private_key_armored_corrupt_deterministic(&self, variant: &str) -> String
pub fn private_key_armored_corrupt_deterministic(&self, variant: &str) -> String
Produce a deterministic corrupted armored private key using a variant string.
Sourcepub fn private_key_binary_truncated(&self, len: usize) -> Vec<u8> ⓘ
pub fn private_key_binary_truncated(&self, len: usize) -> Vec<u8> ⓘ
Produce a truncated private key binary variant.
Sourcepub fn private_key_binary_corrupt_deterministic(&self, variant: &str) -> Vec<u8> ⓘ
pub fn private_key_binary_corrupt_deterministic(&self, variant: &str) -> Vec<u8> ⓘ
Produce a deterministic corrupted private key binary using a variant string.
Sourcepub fn mismatched_public_key_binary(&self) -> Vec<u8> ⓘ
pub fn mismatched_public_key_binary(&self) -> Vec<u8> ⓘ
Return a valid (parseable) public key that does not match this private key.
Sourcepub fn mismatched_public_key_armored(&self) -> String
pub fn mismatched_public_key_armored(&self) -> String
Return an armored public key that does not match this private key.