OpenPGP native adapters for uselesskey fixtures.
Provides conversions to native pgp crate key types from
PgpKeyPair generated fixtures.
Gated behind the native Cargo feature so consumers that only want
the armored/binary byte surface owned by this crate are not pulled
into the native parser surface.
Traits
- PgpNative
Ext - Conversion surface for OpenPGP native key types.